const fs = require('fs');
const path = require('path');
const { URL } = require('url');
const glob = require('glob');
const { injectScript } = require('./inject-script');

module.exports = {
  async onPostBuild({ constants: { CONFIG_PATH, PUBLISH_DIR }, utils }) {
    console.log({ CONFIG_PATH });
    // only enable deploy preview commenting for deploy previews
    if (process.env.CONTEXT !== 'deploy-preview') {
      return;
    }

    // remove iframe security headers
    const headersFile = path.join(PUBLISH_DIR, '_headers');
    const toml = fs.readFileSync(CONFIG_PATH, 'utf-8');
    const headers = fs.readFileSync(headersFile, 'utf-8');

    if (toml) {
      fs.writeFileSync(
        CONFIG_PATH,
        toml.replace(/\s+x-frame-options = ".*\s/gi, '\n'),
        'utf-8',
      );
    }

    if (headers) {
      fs.writeFileSync(
        headersFile,
        headers.replace(/\s+x-frame-options = ".*\s/gi, '\n'),
        'utf-8',
      );
    }

    // add the DPC script to all HTML files
    const files = glob.sync(`${PUBLISH_DIR}/**/*.html`);
    const promises = files.map(injectScript);

    await Promise.all(promises);

    const url = new URL(process.env.DEPLOY_PRIME_URL);
    const [subdomain] = url.hostname.split('.');
    const dpcURL = `https://netlify-dpc.netlify.app/${subdomain}/`;

    utils.status.show({
      title: 'Deploy Preview Commenting enabled!',
      summary: `View and discuss at ${dpcURL}`,
    });
  },
};
